# Iteru


[![image](https://img.shields.io/pypi/v/iteru.svg)](https://pypi.python.org/pypi/iteru)


**Python package for a web app**


-   Free software: MIT license
-   Documentation: https://MuhammedM294.github.io/iteru
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
